@@ -13,7 +13,9 @@ correlation_pearson,
 correlation_categorical,
 correlation_phik,
 quant_variable_study,
-interactions,
+interaction,
+inspection,
 split_and_scaling)
+from . import regression
 
-__version__ = "0.1"
+__version__ = "0.14"
